## 2.4.1 (2021-11-16)

Improve fpdf.image_parsing (#6313)

* Annotate more attributes, arguments, and return types.
* Add "dims" argument to get_img_info(), added in 2.4.6.

## 2.4.0 (2021-11-10)

Add stubs for fpdf2 (#6252)

